@@ -1,7 +1,14 @@
 import os.path
-from .websocket.handler import WebSocketRoute, WebSocketAsync, WebSocketThreaded
+from .websocket.handler import (
+    WebSocketRoute,
+    WebSocketAsync,
+    WebSocketThreaded,
+    WSRPCBase,
+    WebSocketBase,
+)
 from .websocket.route import decorators
-from wsrpc_aiohttp.websocket.client import WSRPCClient
+from .websocket.client import WSRPCClient
+from .websocket.tools import serializer
 
 
 STATIC_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'static')
@@ -10,8 +17,11 @@ STATIC_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'static')
 __all__ = (
     'decorators',
     'STATIC_DIR',
+    'WSRPCBase',
+    'WebSocketBase',
     'WebSocketAsync',
-    'WebSocketRoute',
     'WebSocketThreaded',
+    'WebSocketRoute',
     'WSRPCClient',
+    'serializer',
 )
